package wikipediasearch.view
{
	import mx.collections.ArrayCollection;
	import mx.controls.Alert;
	
	import org.openscales.geometry.basetypes.Location;
	import org.puremvc.as3.interfaces.IMediator;
	import org.puremvc.as3.interfaces.INotification;
	import org.puremvc.as3.patterns.mediator.Mediator;
	
	import wikipediasearch.ApplicationFacade;
	import wikipediasearch.model.SearchProxy;
	import wikipediasearch.model.SearchVO;
	
	public class MainMediator extends Mediator implements IMediator
	{
		public static const NAME:String = "MainMediator";
		
		public function MainMediator(view:Main)
		{
			super(NAME, view);
			
			// Initializations
			cView.btnOpenWiki.enabled = false;
			cView.txtSelectedResult.visible = false;
			
		}
		
		override public function listNotificationInterests():Array
		{
			return [ApplicationFacade.WIKI_SEARCH_SUCCESS,
					ApplicationFacade.WIKI_SEARCH_FAULT,
					ApplicationFacade.WIKI_SELECT_TITLE,
					ApplicationFacade.WIKI_UNSELECT_TITLE];
		}
		
		override public function handleNotification(note:INotification):void {
			switch (note.getName())
			{
				case ApplicationFacade.WIKI_SEARCH_SUCCESS:
					WIKI_SEARCH_SUCCESS_handler();
					break;
				case ApplicationFacade.WIKI_SEARCH_FAULT:
					WIKI_SEARCH_FAULT_handler();
					break;
				case ApplicationFacade.WIKI_SELECT_TITLE:
					WIKI_SELECT_TITLE_handler(note);
					break;
				case ApplicationFacade.WIKI_UNSELECT_TITLE:
					WIKI_UNSELECT_TITLE_handler();
					break;
				default:
					Alert.show("No handler for the notification " + note.getName());
					break;
			}
		}
		
		public function get cView():Main {
			return (viewComponent as Main);
		}
		
		private function WIKI_SEARCH_SUCCESS_handler():void
		{
			var proxy:SearchProxy = facade.retrieveProxy(SearchProxy.NAME) as SearchProxy;
			cView.lstResults.dataProvider = proxy.results;
		}
		
		private function WIKI_SEARCH_FAULT_handler():void
		{
			Alert.show("Cannot connect to Wikipedia");
		}
		
		private function WIKI_SELECT_TITLE_handler(note:INotification):void
		{
			var selectedResult:SearchVO = note.getBody() as SearchVO;
			
			cView.btnOpenWiki.enabled = true;
			cView.txtSelectedResult.visible = true;
			cView.txtSelectedResult.text = selectedResult.summary;
			cView.image.source = selectedResult.thumbnail;
			
			cView.fxmap.map.moveTo(new Location(selectedResult.lon, selectedResult.lat), 14);
		}
		
		private function WIKI_UNSELECT_TITLE_handler():void
		{
			cView.btnOpenWiki.enabled = false;
			cView.txtSelectedResult.visible = false;
			cView.txtSelectedResult.text = "";
			cView.image.source = "http://upload.wikimedia.org/wikipedia/commons/5/5a/Wikipedia-logo-v2-fr.png";
		}
	}
}